﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using BlogEngine.Core;

// Author: Tim Stanley MultiPost User Control: http://Tim-Stanley.com
// Original Idea based on Chris Blankenship's SinglePost: http://www.dscoduc.com 
// http://www.dscoduc.com/post/2008/10/29/Display-SinglePost-User-Control.aspx


public partial class UserCustom_MultiPosts : System.Web.UI.UserControl
{

    List<Post> PostList = new List<Post>();

    #region "Properties"

    private int _Count = 3;
    /// <summary>
    /// How many posts to display.
    /// </summary>
    public int Count
    {
        get
        {
            return _Count;
        }
        set
        {
            _Count = value;
        }
    }

    private bool _ShowDescription = BlogSettings.Instance.ShowDescriptionInPostList;
    /// <summary>
    /// Show the description, not the body.
    /// </summary>
    public bool ShowDescription
    {
        get
        {
            return _ShowDescription;
        }
        set
        {
            _ShowDescription = value;
        }
    }

    private bool _ShowAuthor = true;
    /// <summary>
    /// Show the author name and link.
    /// </summary>
    public bool ShowAuthor
    {
        get
        {
            return _ShowAuthor;
        }
        set
        {
            _ShowAuthor = value;
        }
    }

    private bool _ShowDate = true;
    /// <summary>
    /// Show the date.
    /// </summary>
    public bool ShowDate
    {
        get
        {
            return _ShowDate;
        }
        set
        {
            _ShowDate = value;
        }
    }

    private bool _ShowTitle = true;
    /// <summary>
    /// Show the title.
    /// </summary>
    public bool ShowTitle
    {
        get
        {
            return _ShowTitle;
        }
        set
        {
            _ShowTitle = value;
        }
    }

    private string _DateFormat = "{0:MM/dd/yyyy MM:HH tt}";
    /// <summary>
    /// Date format.
    /// default = {0:MM/dd/yyyy MM:HH tt}
    /// </summary>
    public string DateFormat
    {
        get
        {
            return _DateFormat;
        }
        set
        {
            _DateFormat = value;
        }
    }

    private bool _ShowContent = true;
    /// <summary>
    /// Show the content / body of the post.
    /// </summary>
    public bool ShowContent
    {
        get
        {
            return _ShowContent;
        }
        set
        {
            _ShowContent = value;
        }
    }

    private int _ContentLength = 0;
    /// <summary>
    /// Lenght of Content (or description)
    /// </summary>
    public int ContentLength
    {
        get
        {
            return _ContentLength;
        }
        set
        {
            _ContentLength = value;
        }
    }

    private String _CategoryList = "";
    /// <summary>
    /// Show only the categories in the list.
    /// Seperated by comma's.
    /// </summary>
    public String CategoryList
    {
        get
        {
            return _CategoryList;
        }
        set
        {
            _CategoryList = value.ToUpperInvariant();
        }
    }

    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check if there is at least one post available
        if (Post.Posts.Count > 0)
        {
            AddPosts();
            BindGrid();
        }
    }

    void BindGrid()
    {
        this.PostRepeater1.DataSource = PostList;
        this.PostRepeater1.DataBind();
    }

    void AddPosts()
    {
        int postCount = 0;

        foreach (Post post in Post.Posts)
        {
            Post singlePost = new Post();
            if (post == null)
            {
                break;
            }

            if (singlePost.IsPublished)
            {
                Boolean showPost = false;
                if (CategoryList.Length > 0)
                {
                    for (int i = 0; i < post.Categories.Count; i++)
                    {
                        if (Category.Categories.Contains((Category) post.Categories[i]))
                        {
                            string postCategory = Category.GetCategory(post.Categories[i].Id).Title;
                            postCategory = Utils.RemoveIllegalCharacters(postCategory);
                            if (CategoryList.Contains(postCategory.ToUpperInvariant()))
                            {
                                showPost = true;
                                break;
                            }
                        }
                    }
                }
                else
                {
                    showPost = true;
                }
  
                if (showPost)
                {
                    singlePost.Title = post.Title;
                    singlePost.DateCreated = post.DateCreated;
                    singlePost.Description = post.Description;
                    singlePost.Content = post.Content;
                    singlePost.Author = post.Author;
                    singlePost.IsPublished = post.IsPublished;
                    singlePost.Slug = post.Slug;

                    String szDate = post.DateCreated.ToString(DateFormat);

                    string singlePostDescription;
                    if (ShowDescription)
                    {
                        if (!string.IsNullOrEmpty(singlePost.Description))
                        {
                            singlePostDescription = singlePost.Description;
                        }
                        else
                        {
                            singlePostDescription = Utils.StripHtml(singlePost.Content);
                            // TODO: Future - doesn't strip [more] or other Extensions.  May look confusing.
                            if (singlePostDescription.Length > ContentLength)
                            {
                                singlePostDescription = singlePostDescription.Substring(0, ContentLength) + "...";
                            }
                        }
                        singlePost.Description = singlePostDescription;
                    }

                    PostList.Insert(postCount, singlePost);
                    postCount += 1;
                }
            }

            if (postCount >= Count)
            {
                break;
            }
        }
    }
}

